@@ -1,5 +1,10 @@
 # HELPERS
 
+## https://michaelchirico.github.io/potools/articles/developers.html
+tr_ <- function(...) {
+  enc2utf8(gettext(paste0(...), domain = "R-alkahest"))
+}
+
 #' Find the Nearest Value in a Vector
 #'
 #' @param x A [`numeric`] vector.
