@@ -1,12 +1,10 @@
-# Rectangle rule ===============================================================
 x <- seq(0, 2, len = 101)
 y <- x^3
+z <- data.frame(x, y)
 
-expect_equal(integrate_rectangle(x, y, right = FALSE), 3.9204)
-expect_equal(integrate_rectangle(x, y, right = TRUE), 4.0804)
+# Rectangle rule ===============================================================
+expect_equal(integrate_rectangle(z, right = FALSE), 3.9204)
+expect_equal(integrate_rectangle(z, right = TRUE), 4.0804)
 
 # Trapezoidal rule =============================================================
-x <- seq(0, 2, len = 101)
-y <- x^3
-
-expect_equal(integrate_trapezoid(x, y), 4.0004)
+expect_equal(integrate_trapezoid(z), 4.0004)
